Struct hyper_openssl::HttpsConnector
[−]
[src]
pub struct HttpsConnector<T> { /* fields omitted */ }An Connector using OpenSSL to support http and https schemes.
Methods
impl HttpsConnector<HttpConnector>[src]
fn new(
threads: usize,
handle: &Handle
) -> Result<HttpsConnector<HttpConnector>, ErrorStack>[src]
threads: usize,
handle: &Handle
) -> Result<HttpsConnector<HttpConnector>, ErrorStack>
Creates a new HttpsConnector with default settings and using the
standard Hyper HttpConnector.
impl<T> HttpsConnector<T> where
T: Connect, [src]
T: Connect,
fn with_connector(
http: T,
ssl: SslConnectorBuilder
) -> Result<HttpsConnector<T>, ErrorStack>[src]
http: T,
ssl: SslConnectorBuilder
) -> Result<HttpsConnector<T>, ErrorStack>
Creates a new HttpsConnector.
The session cache configuration of ssl will be overwritten.
fn set_callback<F>(&mut self, callback: F) where
F: Fn(&mut ConnectConfiguration, &Uri) -> Result<(), ErrorStack> + 'static + Sync + Send, [src]
F: Fn(&mut ConnectConfiguration, &Uri) -> Result<(), ErrorStack> + 'static + Sync + Send,
Registers a callback which can customize the configuration of each connection.
It is provided with a reference to the ConnectConfiguration as well as the URI.