Struct hyper_openssl::OpensslClient
[−]
[src]
pub struct OpensslClient { /* fields omitted */ }An SslClient implementation using OpenSSL.
Methods
impl OpensslClient[src]
fn new() -> Result<OpensslClient, ErrorStack>
Creates a new OpenSslClient with default settings.
fn danger_disable_hostname_verification(&mut self, disable_verification: bool)
If set, the
SslConnector::danger_connect_without_providing_domain_for_certificate_verification_and_server_name_indication
method will be used to connect.
If certificate verification has been disabled in the SslConnector, verification must be
additionally disabled here for that setting to take effect.